@@ -397,33 +397,31 @@
         do.call("unlockBinding", list(sym = "write.csv", env = env))
 
          env$write.csv <- function(...) {
-            Call <- as.list(match.call(expand.dots = TRUE))
-    
+            # Call <- as.list(match.call(expand.dots = TRUE))
+            dots <- list(...)
+            
             for (argname in c("append", "col.names", "sep", "dec", "qmethod")) {
-                if (!is.null(Call[[argname]])) {
+                if (!is.null(dots[[argname]])) {
                     warning(gettextf("attempt to set '%s' ignored", argname), domain = NA)
                 }
             }
-
-            rn <- eval.parent(Call$row.names)
             
-            if (any(eval.parent(parse(text = paste0("unlist(lapply(", Call[[2]], ", is_declared))"))))) {
-                Call[[2L]] <- eval.parent(parse(text = paste0("undeclare(", Call[[2L]], ")")))
-                rn <- FALSE
-            }
-            Call$append <- NULL
-            Call$col.names <- if (is.logical(rn) && !rn) {
+            dots[[1L]] <- undeclare(dots[[1L]])
+
+            dots$append <- NULL
+            rn <- dots$row.names
+            dots$col.names <- if (is.logical(rn) && !rn) {
                 TRUE
             }
             else {
                 NA
             }
-            Call$sep <- ","
-            Call$dec <- "."
-            Call$qmethod <- "double"
-            Call$na <- ""
+            dots$sep <- ","
+            dots$dec <- "."
+            dots$qmethod <- "double"
+            dots$na <- ""
 
-            do.call("write.table", Call[-1])
+            do.call("write.table", dots)
         }
     }
 
